pub enum SectioningType {
Article,
Aside,
Nav,
Section,
Root,
Body,
Heading,
}Expand description
The kind of HTML structure represented by an outline structure node.
Variants
Article
An article element.
Aside
An aside element.
A nav element.
Section
A section element.
Root
A generic root used while flattening normal wrapper elements.
Body
A body element.
Heading
An implied outline item created from a heading after the first heading in a section.
Implementations
Sourceimpl SectioningType
impl SectioningType
Sourcepub fn from_sectioning_content_tag<S: AsRef<str>>(
s: S,
) -> Option<SectioningType>
pub fn from_sectioning_content_tag<S: AsRef<str>>( s: S, ) -> Option<SectioningType>
Returns the sectioning content type for the given tag name, or None when the tag is not sectioning content.