pub struct Heading(/* private fields */);Expand description
A heading found in the parsed HTML tree.
Implementations
Sourceimpl Heading
impl Heading
Sourcepub fn get_end_level(&self) -> u8
pub fn get_end_level(&self) -> u8
Returns the heading level at the end of this heading, following the last child heading when this is a group.
Sourcepub fn get_start_level(&self) -> u8
pub fn get_start_level(&self) -> u8
Returns the heading level at the start of this heading, following the first child heading when this is a group.